@@ -31,6 +31,7 @@
 
 #include "file-data.h"
 #include "file-utils.h"
+#include "glib-utils.h"
 #include "fr-command.h"
 #include "fr-command-iso.h"
 
@@ -229,6 +230,8 @@ fr_command_iso_init (FRCommand *comm)
 	FRCommandIso *comm_iso = FR_COMMAND_ISO (comm);
 
 	comm_iso->cur_path = NULL;
+
+	comm->file_type = FR_FILE_TYPE_ISO;
 	
 	comm->propCanModify                = FALSE;
 	comm->propAddCanUpdate             = FALSE;
